import { BlankTerm, IriTerm, LiteralTerm, Pattern } from "sparqljs";
import { SelectedVal } from "../../generators/ISparJson";
import HTMLComponent from "../HtmlComponent";
import LoadingSpinner from "./LoadingSpinner";
export declare enum ValueRepetition {
    SINGLE = 0,
    MULTIPLE = 1
}
export interface WidgetValue {
    value: {
        label: string;
    };
    key: () => string;
}
/**
 * Generic RDFTerm value structure, either an IRI or a Literal with lang or datatype
 */
export declare class RDFTerm {
    type: string;
    value: string;
    "xml:lang"?: string;
    datatype?: string;
}
export declare abstract class AbstractWidget extends HTMLComponent {
    valueRepetition: ValueRepetition;
    protected widgetValues: Array<WidgetValue>;
    startClassVal: SelectedVal;
    objectPropVal: SelectedVal;
    endClassVal: SelectedVal;
    protected blockStartTriple: boolean;
    protected blockObjectPropTriple: boolean;
    protected blockEndTriple: boolean;
    protected spinner: LoadingSpinner;
    constructor(baseCssClass: string, parentComponent: HTMLComponent, widgetHTML: JQuery<HTMLElement>, startClassVal: SelectedVal, objectPropVal: SelectedVal, endClassVal: SelectedVal, valueRepetition: ValueRepetition);
    render(): this;
    abstract getRdfJsPattern(): Pattern[];
    abstract parseInput(value: WidgetValue["value"]): WidgetValue;
    getSparnaturalRepresentation(): string;
    addWidgetValue(widgetValue: WidgetValue): void;
    getLastValue(): WidgetValue;
    getwidgetValues(): WidgetValue[];
    getVariableValue(selectedVal: SelectedVal): string;
    onRemoveValue(val: WidgetValue): void;
    renderWidgetVal(widgetValue: WidgetValue): void;
    renderWidgetValues(widgetValues: WidgetValue[]): void;
    toggleSpinner(message?: string): void;
    isBlockingStart(): boolean;
    isBlockingObjectProp(): boolean;
    isBlockingEnd(): boolean;
    /**
     * Translates an IRI, Literal or BNode into the corresponding SPARQL query term
     * to be inserted in a SPARQL query.
     * @returns
     */
    rdfTermToSparqlQuery(rdfTerm: RDFTerm): IriTerm | BlankTerm | LiteralTerm;
}
